@@ -4,7 +4,6 @@ import abc
 from loguru import logger
 import time
 from nats.aio.msg import Msg
-from nats.js import api
 from nats.js.kv import KeyValue
 from .module.los import los
 from .conf import BaseNodeConf
@@ -38,6 +37,9 @@ class Node(metaclass=abc.ABCMeta):
         cost = time.time() - _tic
         self._fps = 1 / cost
 
+        # 结果包装
+        pmsg = self._warp(pmsg)
+
         # 发送消息
         if self.conf.nats.pub_conf.subject and pmsg is not None:
             _pmsg = bytes('{}'.format(pmsg), 'utf-8')
@@ -63,7 +65,7 @@ class Node(metaclass=abc.ABCMeta):
             logger.debug("sub>>>")
             # 拉取模式
             if self.conf.nats.sub_conf.mode == "pull":
-                osub = self.js.pull_subscribe(
+                osub = await self.js.pull_subscribe(
                     self.conf.nats.sub_conf.subject,
                     durable=self.conf.nats.sub_conf.durable,
                     stream=self.conf.nats.sub_conf.stream,
@@ -71,6 +73,13 @@ class Node(metaclass=abc.ABCMeta):
                     pending_msgs_limit=self.conf.nats.sub_conf.pending_msgs_limit,
                     pending_bytes_limit=self.conf.nats.sub_conf.pending_bytes_limit
                 )
+                while True:
+                    try:
+                        msgs = await osub.fetch(timeout=self.conf.nats.sub_conf.pull_timeout)
+                        msg = msgs[0]
+                        await self._callback(msg)
+                    except TimeoutError:
+                        break
             else:
                 # 推送模式
                 osub = await self.js.subscribe(
@@ -87,12 +96,12 @@ class Node(metaclass=abc.ABCMeta):
                     pending_bytes_limit=self.conf.nats.sub_conf.pending_bytes_limit
                 )
 
-            while True:
-                try:
-                    msg = await osub.next_msg()
-                    await self._callback(msg)
-                except TimeoutError:
-                    break
+                while True:
+                    try:
+                        msg = await osub.next_msg()
+                        await self._callback(msg)
+                    except TimeoutError:
+                        break
         else:
             # 没订阅任何主题时
             while True:
@@ -100,3 +109,11 @@ class Node(metaclass=abc.ABCMeta):
 
     def start(self):
         asyncio.run(self.async_start())
+
+    def _warp(self, pmsg):
+        """
+        对处理结果进行包装
+        :param pmsg:
+        :return:
+        """
+        return {"data": pmsg, "timeat": time.time()}
